
#from distutils.core import setup
import os
import sys
from setuptools import setup, Extension

#This is a list of files to install, and where
#(relative to the 'root' dir, where setup.py is)
#You could be more specific.
files = ["things/*"]

setup(name = "eafsotlogger",
    version = "1.1",
    description = "SOT Library, Maintain log in casandra database using python script.",
    author = "Raj",
    author_email = "raj.pawar@netcore.co.in",
    url = "http://www.netcore.in/",
    #Name the folder where your packages live:
    #(If you have other packages (dirs) or modules (py files) then
    #put them into the package directory - they will be found 
    #recursively.)
    packages = ['soteventlogger'],
    #'package' package must contain files (see list above)
    #I called the package 'package' thus cleverly confusing the whole issue...
    #This dict maps the package name =to=> directories
    #It says, package *needs* these files.
    package_data = {'package' : files },
    #'runner' is in the root.
    scripts = ["runner"],
    long_description = """SOT Library. Maintain all events log in database.""",
    install_requires=[
        "cassandra-driver",
    ],
    #
    #This next part it for the Cheese Shop, look a little down the page.
    classifiers=[      
      'Development Status :: 4 - Beta',
      'Environment :: X11 Applications :: GTK',
      'Intended Audience :: End Users/Desktop',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: GNU General Public License (GPL)',
      'Operating System :: POSIX :: Linux',
      'Programming Language :: Python',
      'Topic :: Desktop Environment',
      'Topic :: Text Processing :: Fonts'
   ],
) 



## Database schema ##
# Please change text to => blob
#CREATE KEYSPACE sot WITH replication = {'class':'SimpleStrategy', 'replication_factor':3};
#CREATE TABLE sot.events (id bigint, event_data text, component varchar, component_name varchar, log_level int, date_added timestamp, PRIMARY KEY (id, date_added));
#CREATE TABLE sot.eventlogs (event_id bigint, msg text, component varchar, component_name varchar, log_level int, date_added timestamp, PRIMARY KEY (event_id, date_added));

from cassandra.cluster import Cluster
from cassandra.auth import PlainTextAuthProvider

class EventLogger:
    con = None

    def __init__(self,nodes, username, password):
        auth_provider = PlainTextAuthProvider(username=username, password=password)
        cluster = Cluster(nodes, protocol_version=2, auth_provider=auth_provider)
        self.con = cluster.connect()
	
    def close(self):
        self.con.cluster.shutdown()
        self.con.shutdown()

    def eventlog(self, eid, event_data, component=None, component_name=None, log_level=None):
    	query1= "INSERT INTO sot.events (id, event_data, component, component_name, log_level, date_added) VALUES (%s, '%s', '%s', '%s', %s, dateof(now()))" %(eid, event_data, component, component_name, log_level) 
    	#print query1
        self.con.execute(query1)
    
    def log(self, event_id, msg, component=None, component_name=None, log_level=None):
    	query2= "INSERT INTO sot.eventlogs (event_id, msg, component, component_name, log_level, date_added) VALUES (%s, '%s', '%s', '%s', %s, dateof(now()))" %(event_id, msg, component, component_name, log_level) 
    	#print query2
        self.con.execute(query2)

def start ():
    print "module is running"

if __name__ == "__main__":
    print "Decide what to do"    